@@ -57,7 +57,14 @@ from ryu.services.protocols.bgp.rtconf.neighbors import PASSWORD
 from ryu.services.protocols.bgp.rtconf.neighbors import IN_FILTER
 from ryu.services.protocols.bgp.rtconf.neighbors import OUT_FILTER
 from ryu.services.protocols.bgp.rtconf.neighbors import IS_ROUTE_SERVER_CLIENT
+from ryu.services.protocols.bgp.rtconf.neighbors import IS_NEXT_HOP_SELF
+from ryu.services.protocols.bgp.rtconf.neighbors import LOCAL_ADDRESS
+from ryu.services.protocols.bgp.rtconf.neighbors import LOCAL_PORT
 from ryu.services.protocols.bgp.info_base.base import Filter
+from ryu.services.protocols.bgp.info_base.ipv4 import Ipv4Path
+from ryu.services.protocols.bgp.info_base.ipv6 import Ipv6Path
+from ryu.services.protocols.bgp.info_base.vpnv4 import Vpnv4Path
+from ryu.services.protocols.bgp.info_base.vpnv6 import Vpnv6Path
 
 
 NEIGHBOR_CONF_MED = 'multi_exit_disc'
@@ -77,16 +84,19 @@ class EventPrefix(object):
     route_dist       None in the case of ipv4 or ipv6 family
     prefix           A prefix was changed
     nexthop          The nexthop of the changed prefix
+    label            mpls label for vpnv4 prefix
     is_withdraw      True if this prefix has gone otherwise False
     ================ ======================================================
 
     """
 
-    def __init__(self, remote_as, route_dist, prefix, nexthop, is_withdraw):
+    def __init__(self, remote_as, route_dist, prefix, nexthop, label,
+                 is_withdraw):
         self.remote_as = remote_as
         self.route_dist = route_dist
         self.prefix = prefix
         self.nexthop = nexthop
+        self.label = label
         self.is_withdraw = is_withdraw
 
 
@@ -142,13 +152,27 @@ class BGPSpeaker(object):
             hub.spawn(ssh.SSH_CLI_CONTROLLER.start)
 
     def _notify_best_path_changed(self, path, is_withdraw):
-        if not path.source:
-            # ours
+        if path.source:
+            nexthop = path.nexthop
+            is_withdraw = is_withdraw
+            remote_as = path.source.remote_as
+        else:
             return
-        ev = EventPrefix(remote_as=path.source.remote_as,
-                         route_dist=None,
-                         prefix=path.nlri.addr + '/' + str(path.nlri.length),
-                         nexthop=path.nexthop, is_withdraw=is_withdraw)
+
+        if isinstance(path, Ipv4Path) or isinstance(path, Ipv6Path):
+            prefix = path.nlri.addr + '/' + str(path.nlri.length)
+            route_dist = None
+            label = None
+        elif isinstance(path, Vpnv4Path) or isinstance(path, Vpnv6Path):
+            prefix = path.nlri.prefix
+            route_dist = path.nlri.route_dist
+            label = path.nlri.label_list
+        else:
+            return
+
+        ev = EventPrefix(remote_as, route_dist, prefix, nexthop, label,
+                         is_withdraw)
+
         if self._best_path_change_handler:
             self._best_path_change_handler(ev)
 
@@ -179,7 +203,9 @@ class BGPSpeaker(object):
                      enable_vpnv4=DEFAULT_CAP_MBGP_VPNV4,
                      enable_vpnv6=DEFAULT_CAP_MBGP_VPNV6,
                      next_hop=None, password=None, multi_exit_disc=None,
-                     site_of_origins=None, is_route_server_client=False):
+                     site_of_origins=None, is_route_server_client=False,
+                     is_next_hop_self=False, local_address=None,
+                     local_port=None):
         """ This method registers a new neighbor. The BGP speaker tries to
         establish a bgp session with the peer (accepts a connection
         from the peer and also tries to connect to it).
@@ -215,6 +241,15 @@ class BGPSpeaker(object):
 
         ``is_route_server_client`` specifies whether this neighbor is a
         router server's client or not.
+
+        ``is_next_hop_self`` specifies whether the BGP speaker announces
+        its own ip address to iBGP neighbor or not as path's next_hop address.
+
+        ``local_address`` specifies Loopback interface address for
+        iBGP peering.
+
+        ``local_port`` specifies source TCP port for iBGP peering.
+
         """
         bgp_neighbor = {}
         bgp_neighbor[neighbors.IP_ADDRESS] = address
@@ -222,6 +257,7 @@ class BGPSpeaker(object):
         bgp_neighbor[PEER_NEXT_HOP] = next_hop
         bgp_neighbor[PASSWORD] = password
         bgp_neighbor[IS_ROUTE_SERVER_CLIENT] = is_route_server_client
+        bgp_neighbor[IS_NEXT_HOP_SELF] = is_next_hop_self
         # v6 advertizement is available with only v6 peering
         if netaddr.valid_ipv4(address):
             bgp_neighbor[CAP_MBGP_IPV4] = enable_ipv4
@@ -243,6 +279,12 @@ class BGPSpeaker(object):
         if site_of_origins:
             bgp_neighbor[SITE_OF_ORIGINS] = site_of_origins
 
+        if local_address:
+            bgp_neighbor[LOCAL_ADDRESS] = local_address
+
+        if local_port:
+            bgp_neighbor[LOCAL_PORT] = local_port
+
         call('neighbor.create', **bgp_neighbor)
 
     def neighbor_del(self, address):
